==> pyqt_openai-1.0.0.tar.gz: pyqt_openai-1.0.0/README.md <==
# VividNode(pyqt-openai)
<div align="center">
  <img src="https://github.com/user-attachments/assets/ab169535-8af0-40c7-848d-59a7e5e4b304"/>

  [![](https://dcbadge.vercel.app/api/server/cHekprskVE)](https://discord.gg/cHekprskVE)
  
  [![PyPI - Version](https://img.shields.io/pypi/v/pyqt-openai?logo=pypi&logoColor=white)](https://pypi.org/project/pyqt-openai/) [![Downloads](https://static.pepy.tech/badge/pyqt-openai)](https://pepy.tech/project/pyqt-openai) [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyqt-openai?logo=python&logoColor=gold)](https://pypi.org/project/pyqt-openai/)
</div>
  
![녹화_2024_08_31_21_42_47_27](https://github.com/user-attachments/assets/03926f12-7389-412c-ad99-36c501573d44)

<hr>

## What is VividNode? 🤔

**VividNode** is a cross-platform desktop application that allows you to interact directly with GPT chatbots (like ChatGPT) and generate images without needing a browser. Built with PySide6, VividNode (formerly known as pyqt-openai) supports Windows, Mac, and Linux, and securely stores your chat history locally in a database.

### Key Features:
- **Chat Interface**: Enjoy a seamless chat experience with a customizable interface, fast thread and message search, and advanced conversation settings. You can also import/export chat histories and use prompt management tools for efficient prompt engineering.
- **Image Generation**: Generate images using OpenAI’s DALL-E 3 or models from Replicate, directly within your chat sessions. The app supports multi-image generation, automatic saving, and integrated image management.
- **Focus and Accessibility Modes**: Utilize Focus Mode, “Always on Top” Mode, transparency adjustments, and background notifications to keep the chat accessible and responsive without overwhelming system resources.
- **Customization and Shortcuts**: VividNode offers extensive customization options, including language settings, memory management, and a comprehensive list of keyboard shortcuts for faster operations.

With VividNode, you can experience a more powerful and resource-efficient alternative to browser-based GPT interfaces, making it easier to manage both text and image-based interactions.

<hr>

## Sidenote 🗒️
Although this is named 'pyqt-openai', the model does not use only OpenAI-related models, and the GUI is created using PySide6, not PyQt. 'pyqt-openai' was the package name decided initially, and we are still using it as changing the package name now would likely result in a huge disaster.

## How to Install

### Install with traditional way
1. git clone ~
2. cd pyqt-openai
3. pip install -r requirements.txt --upgrade
4. cd pyqt_openai
5. You should put your api key in the line edit. You can get it in <a href="https://platform.openai.com/account/api-keys">official site</a> of openai. Sign up and log in before you get it.
6. python main.py

### Install with pyproject.toml 
1. git clone ~
2. Run shell as Administrator
3. cd pyqt-openai
4. pip install .
5. pyqt-openai

### Wanna download this without doing stuffs like above? You can download zip file <a href="https://github.com/yjg30737/pyqt-openai/releases">here</a>

## How to Use 🧐

**<a href="https://medium.com/@yjg30737/what-is-vividnode-how-to-use-it-4d8a9269a3c0">QuickStart</a>**

## Support 🫡

**Join our <a href="https://discord.gg/cHekprskVE">Discord Channel</a>** for questions or discussions!

Also we need <b>contributor</b>, You can contact me 24/7 by sending me an email to yjg30737@gmail.com.

### Donate
  <div>
    <a href='https://ko-fi.com/W7W711SKZG' target='_blank'><img height='36' width='150' style='border:0px;height:36px;' src='https://storage.ko-fi.com/cdn/kofi1.png?v=3' border='0' alt='Buy Me a Coffee at ko-fi.com' /></a>
  </div>
  <a href="https://paypal.me/yjg30737">
    <img src="https://github.com/yjg30737/yjg30737/assets/55078043/3366b496-3e1e-491c-841e-19871da55c40" alt="Donate with PayPal" style="height: 60px; width: 170px" />
  </a>
</div>

## Disclaimer

Please do not distribute this commercially without my permission, by claiming it as your own creation.

==> pyqt_openai-1.1.2.tar.gz: pyqt_openai-1.1.2/README.md <==
# VividNode(pyqt-openai)
<div align="center">
  <img src="https://github.com/user-attachments/assets/ab169535-8af0-40c7-848d-59a7e5e4b304"/>

  [![](https://dcbadge.vercel.app/api/server/cHekprskVE)](https://discord.gg/cHekprskVE)
  
  [![PyPI - Version](https://img.shields.io/pypi/v/pyqt-openai?logo=pypi&logoColor=white)](https://pypi.org/project/pyqt-openai/) [![Downloads](https://static.pepy.tech/badge/pyqt-openai)](https://pepy.tech/project/pyqt-openai) [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyqt-openai?logo=python&logoColor=gold)](https://pypi.org/project/pyqt-openai/)
</div>
  
![녹화_2024_08_31_21_42_47_27](https://github.com/user-attachments/assets/03926f12-7389-412c-ad99-36c501573d44)

<hr>

## What is VividNode? 🤔

**VividNode** is a cross-platform desktop application that allows you to interact directly with GPT chatbots (like ChatGPT) and generate images without needing a browser. Built with PySide6, VividNode (formerly known as pyqt-openai) supports Windows, Mac, and Linux, and securely stores your chat history locally in a database.

### Key Features:
- **Chat Interface**: Enjoy a seamless chat experience with a customizable interface, fast thread and message search, and advanced conversation settings. You can also import/export chat histories and use prompt management tools for efficient prompt engineering.
- **Image Generation**: Generate images using OpenAI’s DALL-E 3 or models from Replicate, directly within your chat sessions. The app supports multi-image generation, automatic saving, and integrated image management.
- **Focus and Accessibility Modes**: Utilize Focus Mode, “Always on Top” Mode, transparency adjustments, and background notifications to keep the chat accessible and responsive without overwhelming system resources.
- **Customization and Shortcuts**: VividNode offers extensive customization options, including language settings, memory management, and a comprehensive list of keyboard shortcuts for faster operations.

With VividNode, you can experience a more powerful and resource-efficient alternative to browser-based GPT interfaces, making it easier to manage both text and image-based interactions.

<hr>

## Sidenote 🗒️
Although this is named 'pyqt-openai', the model does not use only OpenAI-related models, and the GUI is created using PySide6, not PyQt. 'pyqt-openai' was the package name decided initially, and we are still using it as changing the package name now would likely result in a huge disaster.

## How to Install

### Install with traditional way
1. git clone ~
2. cd pyqt-openai
3. pip install -r requirements.txt --upgrade
4. cd pyqt_openai
5. You should put your api key in the line edit. You can get it in <a href="https://platform.openai.com/account/api-keys">official site</a> of openai. Sign up and log in before you get it.
6. python main.py

### Install with pyproject.toml 
1. git clone ~
2. Run shell as Administrator
3. cd pyqt-openai
4. pip install .
5. pyqt-openai

### Wanna download this without doing stuffs like above? You can download installer of zip file <a href="https://github.com/yjg30737/pyqt-openai/releases">here.</a>

## How to Use 🧐

**<a href="https://medium.com/@yjg30737/what-is-vividnode-how-to-use-it-4d8a9269a3c0">QuickStart</a>**

## Support 🫡

**Join our <a href="https://discord.gg/cHekprskVE">Discord Channel</a>** for questions or discussions!

Also we need <b>contributor</b>, You can contact me 24/7 by sending me an email to yjg30737@gmail.com.

### Donate
  <div>
    <a href='https://ko-fi.com/W7W711SKZG' target='_blank'><img height='36' width='150' style='border:0px;height:36px;' src='https://storage.ko-fi.com/cdn/kofi1.png?v=3' border='0' alt='Buy Me a Coffee at ko-fi.com' /></a>
  </div>
  <a href="https://paypal.me/yjg30737">
    <img src="https://github.com/yjg30737/yjg30737/assets/55078043/3366b496-3e1e-491c-841e-19871da55c40" alt="Donate with PayPal" style="height: 60px; width: 170px" />
  </a>
</div>

## Disclaimer

Please do not distribute this commercially without my permission, by claiming it as your own creation.
